@@ -211,6 +211,8 @@ def get_session_name(user_access_key, vtiger_url, vtiger_username):
 
         if status == 200 and response.get('result', ''):
             return response.get('result').get('sessionName')
+        else:
+            print("Can not get Session name from Vtiger. Error occurred with Status", status)
 
 
 def trigger_workflow(workflow, event_type, data, service_url):
@@ -232,8 +234,10 @@ def trigger_workflow(workflow, event_type, data, service_url):
             "eventtype": event_type
         }
 
-    response, status = invoke_http_request(endpoint, 'POST', headers, json_data=payload, timeout=61)
-    print("response", response, "status", status)
+        response, status = invoke_http_request(endpoint, 'POST', headers, json_data=payload, timeout=61)
+        print("response", response, "status", status)
+    else:
+        print("Can not trigger workflow. data is missing")
 
 
 def json_logic_replace_data(rule, data, string_data=None, json_data=None):
@@ -276,49 +280,71 @@ def run_external_workflow(conf, external_workflow_config, vtiger_access):
         # prepare query
         condition = buildquery(search_object.get('condition_object'))
         module = search_object.get('search_module').get('name')
-        limit = str(search_object.get('fetch_record'))
+        limit = str(search_object.get('fetch_record', ''))
 
-        order_by = search_object.get('sort').get('column') + " " + search_object.get('sort').get('type', "")
+        if event_type != 'import' and event_type != 'manual':
+            limit = '1'
 
-        query = 'SELECT * FROM {module} WHERE {condition} order by {order_by} LIMIT {limit};'.format(
-            module=module,
-            condition=condition,
-            order_by=order_by,
-            limit=limit)
+        order_by = ''
+        if search_object.get('sort', ''):
+            order_by = search_object.get('sort').get('column') + " " + search_object.get('sort').get(
+                'type', "")
+
+        if limit and order_by:
+            query = 'SELECT * FROM {module} WHERE {condition} order by {order_by} LIMIT {limit};'.format(
+                module=module,
+                condition=condition,
+                order_by=order_by,
+                limit=limit)
+        elif limit:
+            query = 'SELECT * FROM {module} WHERE {condition} LIMIT {limit};'.format(
+                module=module,
+                condition=condition,
+                limit=limit)
+        elif order_by:
+            query = 'SELECT * FROM {module} WHERE {condition} order by {order_by};'.format(
+                module=module,
+                condition=condition,
+                order_by=order_by,
+            )
+        else:
+            query = 'SELECT * FROM {module} WHERE {condition};'.format(
+                module=module,
+                condition=condition,
+            )
 
         # replace variable name with data using JSON_LOGIC.
         print(f"Query: {query}")
         if rule:
             query = json_logic_replace_data(rule, conf, query)
 
-        if vtiger_access.get('user_access_key', ''):
-            session_name = get_session_name(vtiger_access.get('user_access_key'), vtiger_access.get('vtiger_url'),
-                                            vtiger_access.get('vtiger_username'))
-            if not session_name:
-                print("unable to get session id from dev server. Please try again")
-                return None
+        session_name = vtiger_access.get('vtiger_session', '')
+        print("Session name: {}".format(session_name))
+        if not session_name:
+            print("unable to get session id from vtiger access. Please try again")
+            return None
 
-            url = '{vtiger_url}/webservice.php?operation=query&sessionName={sessionName}&query={query}'.format(
-                sessionName=session_name, query=query, vtiger_url=vtiger_access.get('vtiger_url'))
-            print(f"Url: {url}")
-            headers = {'content-type': 'application/json'}
-            request_type = 'GET'
-            response, status = invoke_http_request(url, request_type, headers)
+        url = '{vtiger_url}/webservice.php?operation=query&sessionName={sessionName}&query={query}'.format(
+            sessionName=session_name, query=query, vtiger_url=vtiger_access.get('vtiger_url'))
+        print(f"Url: {url}")
+        headers = {'content-type': 'application/json'}
+        request_type = 'GET'
+        response, status = invoke_http_request(url, request_type, headers)
 
-            print(f"Response: {response}")
+        print(f"Response: {response}")
 
-            if response:
-                # trigger only if condition is satisfied
-                if response.get('result') and workflow and event_type:
+        if response:
+            # trigger only if condition is satisfied
+            if response.get('result') and workflow and event_type:
 
-                    if event_type == 'import' or event_type == 'manual':
-                        # if event type = import/ manual then pass list
+                if event_type == 'import' or event_type == 'manual':
+                    # if event type = import/ manual then pass list
 
-                        trigger_workflow(workflow, event_type, response.get('result'),
-                                         vtiger_access.get('service_url'))
-                    else:
-                        trigger_workflow(workflow, event_type, response.get('result')[0],
-                                         vtiger_access.get('service_url'))
+                    trigger_workflow(workflow, event_type, response.get('result'),
+                                     vtiger_access.get('service_url'))
+                else:
+                    trigger_workflow(workflow, event_type, response.get('result')[0],
+                                     vtiger_access.get('service_url'))
     elif workflow and event_type and data:
         # trigger without condition
         if event_type == 'import' or event_type == 'manual':
@@ -406,14 +432,11 @@ def invoke_set_value_task(conf, set_value_configs, vtiger_access):
     search_module_object = set_value_configs.get('search_module_object', '')
     rule = set_value_configs.get('rule', '')
 
-    session_name = ''
-    if vtiger_access.get('user_access_key', ''):
-        session_name = get_session_name(vtiger_access.get('user_access_key'), vtiger_access.get('vtiger_url'),
-                                        vtiger_access.get('vtiger_username'))
-        print("Session name: {}".format(session_name))
-        if not session_name:
-            print("unable to get session id from vtiger server. Please try again")
-            return None
+    session_name = vtiger_access.get('vtiger_session', '')
+    print("Session name: {}".format(session_name))
+    if not session_name:
+        print("unable to get session id from vtiger access. Please try again")
+        return None
 
     print("Search module object: {}".format(search_module_object))
     print("Set value fields: {}".format(set_value_fields))
@@ -506,7 +529,10 @@ def invoke_web_service_task(conf, web_service_configs):
         payload = request_object.get("payload")
 
         if payload:
-            response, status = invoke_http_request(url, request_type, headers, json_data=payload)
+            if headers.get('content-type', '') == 'application/json':
+                response, status = invoke_http_request(url, request_type, headers, json_data=payload)
+            else:
+                response, status = invoke_http_request(url, request_type, headers, payload=payload)
         else:
             response, status = invoke_http_request(url, request_type, headers)
         if is_success_request(status):
